@@ -25,17 +25,20 @@
 This is an internal PyTango module.
 """
 
-__all__ = []
+__all__ = ["connection_init"]
 
 __docformat__ = "restructuredtext"
 
-from _PyTango import Connection, DeviceData, __CallBackAutoDie, CmdArgType
-from _PyTango import DeviceProxy, Database
-from _PyTango import ExtractAs
-from utils import document_method as __document_method
 import operator
 
-def __CallBackAutoDie__cmd_ended_aux(fn):
+from ._PyTango import Connection, DeviceData, __CallBackAutoDie, CmdArgType, \
+    DeviceProxy, Database, ExtractAs
+from .utils import document_method as __document_method
+from .utils import document_static_method as __document_static_method
+import collections
+
+
+def __CallBackAutoDie__cmd_ended_aux(self, fn):
     def __new_fn(cmd_done_event):
         try:
             cmd_done_event.argout = cmd_done_event.argout_raw.extract(
@@ -66,7 +69,7 @@ def __get_command_inout_param(self, cmd_name, cmd_param=None):
         if isinstance(cmd_param, str):
             param.insert(CmdArgType.DevString, cmd_param)
             return param
-        elif operator.isSequenceType(cmd_param) and all([isinstance(x,str) for x in cmd_param]):
+        elif isinstance(cmd_param, collections.Sequence) and all([isinstance(x,str) for x in cmd_param]):
             param.insert(CmdArgType.DevVarStringArray, cmd_param)
             return param
         else:
@@ -164,14 +167,14 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
         forget = False
         return self.__command_inout_asynch_id(cmd_name, argin, forget)
     elif len(args) == 1:
-        if callable(args[0]): # command_inout_asynch(lambda)
+        if isinstance(args[0], collections.Callable): # command_inout_asynch(lambda)
             cb = __CallBackAutoDie()
-            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(args[0])
+            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[0])
             argin = __get_command_inout_param(self, cmd_name)
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         elif hasattr(args[0], 'cmd_ended'): # command_inout_asynch(Cbclass)
             cb = __CallBackAutoDie()
-            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(args[0].cmd_ended)
+            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[0].cmd_ended)
             argin = __get_command_inout_param(self, cmd_name)
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         else: # command_inout_asynch(value)
@@ -179,14 +182,14 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
             forget = False
             return self.__command_inout_asynch_id(cmd_name, argin, forget)
     elif len(args) == 2:
-        if callable(args[1]): #command_inout_asynch( value, lambda)
+        if isinstance(args[1], collections.Callable): #command_inout_asynch( value, lambda)
             cb = __CallBackAutoDie()
-            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(args[1])
+            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[1])
             argin = __get_command_inout_param(self, cmd_name, args[0])
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         elif hasattr(args[1], 'cmd_ended'): #command_inout_asynch(value, cbClass)
             cb = __CallBackAutoDie()
-            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(args[1].cmd_ended)
+            cb.cmd_ended = __CallBackAutoDie__cmd_ended_aux(self, args[1].cmd_ended)
             argin = __get_command_inout_param(self, cmd_name, args[0])
             return self.__command_inout_asynch_cb(cmd_name, argin, cb)
         else: # command_inout_asynch(value, forget)
@@ -253,6 +256,9 @@ def __doc_Connection():
     def document_method(method_name, desc, append=True):
         return __document_method(Connection, method_name, desc, append)
 
+    def document_static_method(method_name, desc, append=True):
+        return __document_static_method(Connection, method_name, desc, append)
+    
     Connection.__doc__ = """
         The abstract Connection class for DeviceProxy. Not to be initialized directly.
     """
@@ -531,6 +537,7 @@ def __doc_Connection():
 
     document_method("set_access_control", """
     set_access_control(self, acc) -> None
+            
             Sets the current access control type
             
         Parameters :
@@ -541,7 +548,62 @@ def __doc_Connection():
         New in PyTango 7.0.0
     """)
 
-def init(doc=True):
+    document_method("get_access_right", """
+    get_access_right(self) -> AccessControlType
+    
+            Returns the current access control type
+            
+        Parameters : None
+        Return     : (AccessControlType) The current access control type
+
+        New in PyTango 8.0.0
+    """)
+
+    document_static_method("get_fqdn", """
+    get_fqdn(self) -> str
+    
+            Returns the fully qualified domain name
+
+        Parameters : None
+        Return     : (str) the fully qualified domain name
+        
+        New in PyTango 7.2.0
+    """)
+
+    document_method("is_dbase_used", """
+    is_dbase_used(self) -> bool
+            
+            Returns if the database is being used
+            
+        Parameters : None
+        Return     : (bool) True if the database is being used
+
+        New in PyTango 7.2.0
+    """)
+    
+    document_method("get_dev_host", """
+    get_dev_host(self) -> str
+            
+            Returns the current host
+            
+        Parameters : None
+        Return     : (str) the current host
+
+        New in PyTango 7.2.0
+    """)
+    
+    document_method("get_dev_port", """
+    get_dev_port(self) -> str
+            
+            Returns the current port
+            
+        Parameters : None
+        Return     : (str) the current port
+
+        New in PyTango 7.2.0
+    """)
+    
+def connection_init(doc=True):
     __init_Connection()
     if doc:
         __doc_Connection()
