@@ -1,43 +1,43 @@
-#############################################################################
+################################################################################
 ##
 ## This file is part of PyTango, a python binding for Tango
-##
+## 
 ## http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
 ##
-## (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
-## This is free software; you can redistribute it and/or modify
+## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+## 
+## PyTango is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
+## the Free Software Foundation, either version 3 of the License, or
 ## (at your option) any later version.
-##
-## This software is distributed in the hope that it will be useful,
+## 
+## PyTango is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU Lesser General Public License for more details.
-##
+## 
 ## You should have received a copy of the GNU Lesser General Public License
-## along with this program; if not, see <http://www.gnu.org/licenses/>.
-###########################################################################
+## along with PyTango.  If not, see <http://www.gnu.org/licenses/>.
+##
+################################################################################
 
 """
 This is an internal PyTango module.
 """
 
-__all__ = [ "Util" ]
+__all__ = [ "Util", "pyutil_init" ]
 
 __docformat__ = "restructuredtext"
 
 import os
 import copy
-import operator
 
-from _PyTango import _Util, Except, DevFailed, DbDevInfo
-from utils import document_method as __document_method
+from ._PyTango import _Util, Except, DevFailed, DbDevInfo
+from .utils import document_method as __document_method
 #from utils import document_static_method as __document_static_method
-from globals import class_list
-from globals import cpp_class_list
-from globals import get_constructed_classes
+from .globals import class_list, cpp_class_list, get_constructed_classes
+import collections
+
 
 def __simplify_device_name(dev_name):
     if dev_name.startswith("tango://"):
@@ -91,7 +91,7 @@ def __Util__create_device(self, klass_name, device_name, alias=None, cb=None):
                    device name (str). Default value is None meaning no callback
         
         Return     : None"""
-    if cb is not None and not callable(cb):
+    if cb is not None and not isinstance(cb, collections.Callable):
         Except.throw_exception("PyAPI_InvalidParameter",
             "The optional cb parameter must be a python callable",
             "Util.create_device")
@@ -103,7 +103,7 @@ def __Util__create_device(self, klass_name, device_name, alias=None, cb=None):
     device_exists = True
     try:
         db.import_device(device_name)
-    except DevFailed, df:
+    except DevFailed as df:
         device_exists = not df[0].reason == "DB_DeviceNotDefined"
 
     # 1 - Make sure device name doesn't exist already in the database
@@ -177,7 +177,7 @@ def __Util__delete_device(self, klass_name, device_name):
     device_exists = True
     try:
         db.import_device(device_name)
-    except DevFailed, df:
+    except DevFailed as df:
         device_exists = not df[0].reason == "DB_DeviceNotDefined"
 
     # 1 - Make sure device name exists in the database
@@ -217,12 +217,10 @@ class Util(_Util):
 
         This class is implemented using the singleton design pattern.
         Therefore a device server process can have only one instance of this
-        class and its constructor is not public.
-
-            Example:
-                util = PyTango.Util.instance()
-                print util.get_host_name()
-        """
+        class and its constructor is not public. Example::
+            
+            util = PyTango.Util.instance()
+            print(util.get_host_name())"""
 
     def __init__(self, args):
         args = copy.copy(args)
@@ -231,11 +229,13 @@ class Util(_Util):
         _Util.init_python()
 
     def add_TgClass(self, klass_device_class, klass_device, device_class_name=None):
-        """Register a new python tango class.
+        """Register a new python tango class. Example::
            
-           Example:
                util.add_TgClass(MotorClass, Motor)
-               util.add_TgClass(MotorClass, Motor, 'Motor') # equivalent to previous line"""
+               util.add_TgClass(MotorClass, Motor, 'Motor') # equivalent to previous line
+           
+           .. deprecated:: 7.1.2
+               Use :meth:`PyTango.Util.add_class` instead."""
                
         if device_class_name is None:
             device_class_name = klass_device.__name__
@@ -246,12 +246,15 @@ class Util(_Util):
         """Register a new C++ tango class.
            
            If there is a shared library file called MotorClass.so which
-           contains a MotorClass class and a _create_MotorClass_class method.
-           Example:
+           contains a MotorClass class and a _create_MotorClass_class method. Example::
+           
                util.add_Cpp_TgClass('MotorClass', 'Motor')
                
-           .. note: the parameter 'device_class_name' must match the shared
-           library name."""
+           .. note:: the parameter 'device_class_name' must match the shared
+                     library name.
+                    
+           .. deprecated:: 7.1.2
+               Use :meth:`PyTango.Util.add_class` instead."""
         cpp_class_list.append((device_class_name, tango_device_class_name))
 
     def add_class(self, *args, **kwargs):
@@ -262,9 +265,8 @@ class Util(_Util):
            
                 If language is 'python' then args must be the same as 
                 :meth:`PyTango.Util.add_TgClass`. Otherwise, args should be the ones
-                in :meth:`PyTango.Util.add_Cpp_TgClass`.
-            
-                Example:
+                in :meth:`PyTango.Util.add_Cpp_TgClass`. Example::
+                
                     util.add_class(MotorClass, Motor)
                     util.add_class('CounterClass', 'Counter', language='c++')
            
@@ -292,7 +294,7 @@ def __doc_Util():
 #
 #            Static method that gets the singleton object reference.
 #            If the class has not been initialised with it's init method,
-#            this method print a message and abort the device server process
+#            this method prints a message and aborts the device server process
 #
 #        Parameters :
 #            - exit : (bool)
@@ -556,7 +558,42 @@ def __doc_Util():
         Parameters : None
         Return     : (int) the maximun number of threads in the polling threads pool
     """ )
-    
+
+    document_method("is_svr_starting", """
+    is_svr_starting(self) -> bool
+
+            Check if the device server process is in its starting phase
+
+        Parameters : None
+        Return     : (bool) True if the server is in its starting phase
+
+        New in PyTango 8.0.0
+    """ )
+
+    document_method("is_svr_shutting_down", """
+    is_svr_shutting_down(self) -> bool
+
+            Check if the device server process is in its shutting down sequence
+
+        Parameters : None
+        Return     : (bool) True if the server is in its shutting down phase.
+
+        New in PyTango 8.0.0
+    """ )
+
+    document_method("is_device_restarting", """
+    is_device_restarting(self, (str)dev_name) -> bool
+
+            Check if the device is actually restarted by the device server
+            process admin device with its DevRestart command
+
+        Parameters :
+            dev_name : (str) device name
+        Return     : (bool) True if the device is restarting.
+
+        New in PyTango 8.0.0
+    """ )
+            
     document_method("get_sub_dev_diag", """
     get_sub_dev_diag(self) -> SubDevDiag
 
@@ -664,7 +701,7 @@ def __doc_Util():
 #        Return     : None
 #    """ )
 
-def init(doc=True):
+def pyutil_init(doc=True):
     __init_Util()
     if doc:
         __doc_Util()
