@@ -26,23 +26,26 @@ This is an internal PyTango module.
 """
 
 from __future__ import with_statement
+from __future__ import print_function
 
-__all__ = [ "is_scalar_type", "is_array_type", "is_numerical_type", 
+__all__ = [ "is_pure_str", "is_seq", "is_non_str_seq", "is_integer",
+            "is_number", "is_scalar_type", "is_array_type", "is_numerical_type",
             "is_int_type", "is_float_type", "obj_2_str", "seqStr_2_obj",
             "document_method", "document_static_method", "document_enum",
-            "CaselessList", "CaselessDict", "EventCallBack", "get_home" ]
+            "CaselessList", "CaselessDict", "EventCallBack", "get_home",
+            "from_version_str_to_hex_str", "from_version_str_to_int", ]
 
 __docformat__ = "restructuredtext"
 
 import sys
 import os
-import socket
-import types
-import operator
+import collections
+import numbers
 
-from _PyTango import StdStringVector, DbData, DbDevInfos, DbDevExportInfos, CmdArgType, AttrDataFormat
-from _PyTango import EventData, AttrConfEventData, DataReadyEventData
-from _PyTango import ApiUtil
+from ._PyTango import StdStringVector, StdDoubleVector, \
+    DbData, DbDevInfos, DbDevExportInfos, CmdArgType, AttrDataFormat, \
+    EventData, AttrConfEventData, DataReadyEventData, DevFailed
+from ._PyTango import constants
 
 _scalar_int_types = (CmdArgType.DevShort, CmdArgType.DevUShort,
     CmdArgType.DevInt, CmdArgType.DevLong, CmdArgType.DevULong,
@@ -87,6 +90,50 @@ _scalar_to_array_type = {
     CmdArgType.ConstDevString : CmdArgType.DevVarStringArray,
 }
 
+__str_klasses = str,
+__int_klasses = int,
+__number_klasses = numbers.Number,
+
+__use_unicode = False
+try:
+    unicode
+    __use_unicode = True
+    __str_klasses = tuple(list(__str_klasses) + [unicode])
+except:
+    pass
+
+__use_long = False
+try:
+    long
+    __use_long = True
+    __int_klasses = tuple(list(__int_klasses) + [long])
+except:
+    pass
+
+if constants.NUMPY_SUPPORT:
+    import numpy
+    __int_klasses = tuple(list(__int_klasses) + [numpy.integer])
+    __number_klasses = tuple(list(__number_klasses) + [numpy.number])
+
+__str_klasses = tuple(__str_klasses)
+__int_klasses = tuple(__int_klasses)
+__number_klasses = tuple(__number_klasses)
+
+def is_pure_str(obj):
+    return isinstance(obj , __str_klasses)
+
+def is_seq(obj):
+    return isinstance(obj, (collections.Sequence, bytearray))
+
+def is_non_str_seq(obj):
+    return is_seq(obj) and not is_pure_str(obj)
+
+def is_integer(obj):
+    return isinstance(obj, __int_klasses)
+
+def is_number(obj):
+    return isinstance(obj, __number_klasses)
+
 def is_scalar(tg_type):
     """Tells if the given tango type is a scalar
     
@@ -246,7 +293,7 @@ def StdDoubleVector_2_seq(vec, seq=None):
     if seq is None: seq = []
     if not isinstance(vec, StdDoubleVector):
         raise TypeError('vec must be a PyTango.StdDoubleVector')
-    for e in vec: sec.append(float(e))
+    for e in vec: seq.append(float(e))
     return seq
 
 def seq_2_DbDevInfos(seq, vec=None):
@@ -332,8 +379,8 @@ def seqStr_2_obj(seq, tg_type, tg_format=None):
 
 def _seqStr_2_obj_from_type(seq, tg_type):
     
-    if type(seq) in types.StringTypes:
-        seq = (seq,)
+    if is_pure_str(seq):
+        seq = seq,
     
     #    Scalar cases
     global _scalar_int_types
@@ -422,7 +469,7 @@ def obj_2_str(obj, tg_type):
     ret = ""
     if tg_type in _scalar_types:
         # scalar cases
-        if operator.isSequenceType(obj):
+        if isinstance(obj, collections.Sequence):
             if not len(obj):
                 return ret
             obj = obj[0]
@@ -432,25 +479,39 @@ def obj_2_str(obj, tg_type):
         ret = '\n'.join([ str(i) for i in obj ])
     return ret
 
+def __get_meth_func(klass, method_name):
+    meth = getattr(klass, method_name)
+    func = meth
+    if hasattr(meth, '__func__'):
+        func = meth.__func__
+    elif hasattr(meth, 'im_func'):
+        func = meth.im_func
+    return meth, func
+
 def copy_doc(klass, fnname):
-    """Copies documentation string of a method from the super class into the rewritten method of the given class"""
-    getattr(klass, fnname).im_func.__doc__ = getattr(klass.__base__, fnname).im_func.__doc__
+    """Copies documentation string of a method from the super class into the
+    rewritten method of the given class"""
+    base_meth, base_func = __get_meth_func(klass.__base__, fnname)
+    meth, func = __get_meth_func(klass, fnname)
+    func.__doc__ = base_func.__doc__
 
 def document_method(klass, method_name, d, add=True):
+    meth, func = __get_meth_func(klass, method_name)
     if add:
-        cpp_doc = getattr(klass, method_name).__doc__
+        cpp_doc = meth.__doc__
         if cpp_doc:
-            getattr(klass, method_name).im_func.__doc__ = "%s\n%s" % (d, cpp_doc)
+            func.__doc__ = "%s\n%s" % (d, cpp_doc)
             return
-    getattr(klass, method_name).im_func.__doc__ = d
+    func.__doc__ = d
 
 def document_static_method(klass, method_name, d, add=True):
+    meth, func = __get_meth_func(klass, method_name)
     if add:
-        cpp_doc = getattr(klass, method_name).__doc__
+        cpp_doc = meth.__doc__
         if cpp_doc:
-            getattr(klass, method_name).__doc__ = "%s\n%s" % (d, cpp_doc)
+            meth.__doc__ = "%s\n%s" % (d, cpp_doc)
             return
-    getattr(klass, method_name).__doc__ = d
+    meth.__doc__ = d
 
 def document_enum(klass, enum_name, desc, append=True):
     # derived = type(base)('derived', (base,), {'__doc__': 'desc'})
@@ -722,17 +783,17 @@ def notifd2db(notifd_ior_file=__DEFAULT_FACT_IOR_FILE, files=None, host=None, ou
 def _notifd2db_file_db(ior_string, files, out=sys.stdout):
     raise RuntimeError("Not implemented yet")
 
-    print >>out, "going to export notification service event factory to " \
-                 "device server property file(s) ..."
+    print("going to export notification service event factory to " \
+          "device server property file(s) ...", file=out)
     for f in files:
-        with file(f, "w") as out_file:
+        with file(f, "w"):
             pass
     return
 
 def _notifd2db_real_db(ior_string, host=None, out=sys.stdout):
     import PyTango
-    print >>out, "going to export notification service event factory to " \
-                 "Tango database ..."
+    print("going to export notification service event factory to " \
+          "Tango database ...", file=out)
                  
     num_retries = 3
     while num_retries > 0:
@@ -740,15 +801,16 @@ def _notifd2db_real_db(ior_string, host=None, out=sys.stdout):
             db = PyTango.Database()
             db.set_timeout_millis(10000)
             num_retries = 0
-        except PyTango.DevFailed, df:
+        except PyTango.DevFailed as df:
             num_retries -= 1
             if num_retries == 0:
-                print >>out, "Can't create Tango database object"
-                print >>out, str(df)
+                print("Can't create Tango database object", file=out)
+                print(str(df), file=out)
                 return
-            print >>out, "Can't create Tango database object, retrying...."
+            print("Can't create Tango database object, retrying....", file=out)
     
     if host is None:
+        import socket
         host_name = socket.getfqdn()
     
     global __NOTIFD_FACTORY_PREFIX
@@ -759,25 +821,25 @@ def _notifd2db_real_db(ior_string, host=None, out=sys.stdout):
     num_retries = 3
     while num_retries > 0:
         try:
-            ret = db.command_inout("DbExportEvent", args)
-            print >>out, "Successfully exported notification service event " \
-                         "factory for host", host_name, "to Tango database !"
+            db.command_inout("DbExportEvent", args)
+            print("Successfully exported notification service event " \
+                  "factory for host", host_name, "to Tango database !", file=out)
             break
-        except PyTango.CommunicationFailed, cf:
+        except PyTango.CommunicationFailed as cf:
             if len(cf.errors) >= 2:
-                if e.errors[1].reason == "API_DeviceTimedOut":
+                if cf.errors[1].reason == "API_DeviceTimedOut":
                     if num_retries > 0:
                         num_retries -= 1
                 else:
                     num_retries = 0
             else:
                 num_retries = 0
-        except Exception, e:
+        except Exception:
             num_retries = 0
     
     if num_retries == 0:
-        print >>out, "Failed to export notification service event factory " \
-                     "to TANGO database"
+        print("Failed to export notification service event factory " \
+              "to TANGO database", file=out)
 
 
 class EventCallBack(object):
@@ -823,19 +885,43 @@ class EventCallBack(object):
         """Internal usage only"""
         try:
             self._push_event(evt)
-        except Exception, e:
-            print >>self._fd, "Unexpected error in callback: %s" % str(e)
+        except Exception as e:
+            print("Unexpected error in callback for %s: %s" \
+                  % (str(evt), str(e)), file=self._fd)
     
     def _push_event(self, evt):
         """Internal usage only"""
         self._append(evt)
-        d = { "date" : evt.get_date().todatetime(),
-              "reception_date" : evt.reception_date.todatetime(),
-              "type" : evt.event.upper(),
-              "dev_name" : evt.device.dev_name().upper(),
-              "name" : evt.attr_name.split("/")[-1].upper(),
-              "value" : self._get_value(evt) }
-        print >>self._fd, self._msg.format(**d)
+        import datetime
+        now = datetime.datetime.now()
+        try:
+            date = evt.get_date().todatetime()
+        except:
+            date = now
+        try:
+            reception_date = evt.reception_date.todatetime()
+        except:
+            reception_date = now
+        try:
+            evt_type = evt.event.upper()
+        except:
+            evt_type = "<UNKNOWN>"
+        try:
+            dev_name = evt.device.dev_name().upper()
+        except:
+            dev_name = "<UNKNOWN>"
+        try:
+            attr_name = evt.attr_name.split("/")[-1].upper()
+        except:
+            attr_name = "<UNKNOWN>"
+        try:
+            value = self._get_value(evt)
+        except Exception as e:
+            value = "Unexpected exception in getting event value: %s" % str(e)
+        d = { "date" : date, "reception_date" : reception_date,
+              "type" : evt_type, "dev_name" : dev_name, "name" : attr_name,
+              "value" : value }
+        print(self._msg.format(**d), file=self._fd)
 
     def _append(self, evt):
         """Internal usage only"""
@@ -926,4 +1012,68 @@ def _get_env_var(env_var_name):
         
         key, val = map(str.strip, tup)
         if key == env_var_name:
-            return val
\ No newline at end of file
+            return val
+
+def from_version_str_to_hex_str(version_str):
+    v = map(int, version_str.split('.'));
+    return "0x%02d%02d%02d00" % (v[0],v[1],v[2])
+
+def from_version_str_to_int(version_str):
+    return int(from_version_str_to_hex_str(version_str, 16))
+
+def __server_run(classes, args=None, msg_stream=sys.stderr):
+    import PyTango
+    if msg_stream is None:
+        import io
+        msg_stream = io.BytesIO()
+    
+    if args is None:
+        args = sys.argv
+    util = PyTango.Util(args)
+
+    for klass_name, (klass_klass, klass) in classes.items():
+        util.add_class(klass_klass, klass, klass_name)
+    u_instance = PyTango.Util.instance()
+    u_instance.server_init()
+    msg_stream.write("Ready to accept request\n")
+    u_instance.server_run()
+    
+def server_run(classes, args=None, msg_stream=sys.stderr):
+    """Provides a simple way to run a tango server. It handles exceptions
+       by writting a message to the msg_stream
+       
+       For example, if you want to expose a server of type "MyServer" which
+       is defined by tango classes `MyServerClass` and `MyServer` then::
+       
+           import PyTango
+           PyTango.server_run({"MyServer": (MyServerClass, MyServer)})
+        
+       :param classes:
+           a dictionary where keyword is the tango class name and value is a 
+           sequence of Tango Class python class, and Tango python class
+       :type classes: dict
+       
+       :param args:
+           list of command line arguments [default: None, meaning use sys.argv]
+       :type args: list
+       
+       :param msg_stream:
+           stream where to put messages [default: sys.stderr]
+       
+       .. versionadded:: 8.0.0"""
+       
+    if msg_stream is None:
+        import io
+        msg_stream = io.BytesIO()
+    write = msg_stream.write
+    try:
+        return __server_run(classes, args=args)
+        write("Exiting:\n")
+    except KeyboardInterrupt:
+        write("Exiting: Keyboard interrupt\n")
+    except DevFailed as df:
+        write("Exiting: Server exited with PyTango.DevFailed:\n" + str(df) + "\n")
+    except Exception as e:
+        write("Exiting: Server exited with unforseen exception:\n" + str(e) + "\n")
+    write("\nExited\n")
+
