@@ -4,20 +4,20 @@
 
    http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
 
-   (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
-  
-   This is free software; you can redistribute it and/or modify
+   Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+   
+   PyTango is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-  
-   This software is distributed in the hope that it will be useful,
+   
+   PyTango is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.
   
    You should have received a copy of the GNU Lesser General Public License
-   along with this program; if not, see <http://www.gnu.org/licenses/>.
+   along with PyTango.  If not, see <http://www.gnu.org/licenses/>.
    
 *******************************************************************************/
 
@@ -149,11 +149,11 @@ struct from_py<tangoTypeConst> \
                     boost::python::throw_error_already_set();  \
             } \
             if (TangoScalarTypeLimits::is_integer) { \
-                if (cpy_value > TangoScalarTypeLimits::max()) { \
+                if (cpy_value > (cpy_type)TangoScalarTypeLimits::max()) { \
                     PyErr_SetString(PyExc_OverflowError, "Value is too large."); \
                     boost::python::throw_error_already_set(); \
                 } \
-                if (cpy_value < TangoScalarTypeLimits::min()) { \
+                if (cpy_value < (cpy_type)TangoScalarTypeLimits::min()) { \
                     PyErr_SetString(PyExc_OverflowError, "Value is too small."); \
                     boost::python::throw_error_already_set(); \
                 } \
@@ -176,18 +176,6 @@ DEFINE_FAST_TANGO_FROMPY_NUM(Tango::DEV_ULONG64, Tango::DevULong64, PyLong_AsUns
 DEFINE_FAST_TANGO_FROMPY_NUM(Tango::DEV_FLOAT, double, PyFloat_AsDouble)
 DEFINE_FAST_TANGO_FROMPY_NUM(Tango::DEV_DOUBLE, double, PyFloat_AsDouble)
 
-/// @bug Not a bug per se, but you should keep in mind: It returns a new
-/// string, so if you pass it to Tango with a release flag there will be
-/// no problems, but if you have to use it yourself then you must remember
-/// to delete[] it!
-inline Tango::DevString PyString_AsCorbaString(PyObject* ob)
-{
-    const char* str = PyString_AsString(ob);
-    if (!str)
-        return 0;
-    return CORBA::string_dup(str);
-}
-
 // DEFINE_FAST_TANGO_FROMPY(Tango::DEV_STRING, PyString_AsString)
 DEFINE_FAST_TANGO_FROMPY(Tango::DEV_STRING, PyString_AsCorbaString)
 
@@ -679,13 +667,13 @@ inline TANGO_const2type(Tango::DEVVAR_LONGSTRINGARRAY)* fast_convert2array<Tango
         &py_lng = py_value[0],
         &py_str = py_value[1];
 
-    std::auto_ptr<Tango::DevVarLongArray> a_lng(
+    unique_pointer<Tango::DevVarLongArray> a_lng(
         fast_convert2array<Tango::DEVVAR_LONGARRAY>(py_lng));
 
-    std::auto_ptr<Tango::DevVarStringArray> a_str(
+    unique_pointer<Tango::DevVarStringArray> a_str(
         fast_convert2array<Tango::DEVVAR_STRINGARRAY>(py_str));
 
-    std::auto_ptr<TangoArrayType> result(new TangoArrayType());
+    unique_pointer<TangoArrayType> result(new TangoArrayType());
 
     result->lvalue = *a_lng;
     result->svalue = *a_str;
@@ -714,13 +702,13 @@ inline TANGO_const2type(Tango::DEVVAR_DOUBLESTRINGARRAY)* fast_convert2array<Tan
         &py_dbl = py_value[0],
         &py_str = py_value[1];
 
-    std::auto_ptr<Tango::DevVarDoubleArray> a_dbl(
+    unique_pointer<Tango::DevVarDoubleArray> a_dbl(
         fast_convert2array<Tango::DEVVAR_DOUBLEARRAY>(py_dbl));
 
-    std::auto_ptr<Tango::DevVarStringArray> a_str(
+    unique_pointer<Tango::DevVarStringArray> a_str(
         fast_convert2array<Tango::DEVVAR_STRINGARRAY>(py_str));
 
-    std::auto_ptr<TangoArrayType> result(new TangoArrayType());
+    unique_pointer<TangoArrayType> result(new TangoArrayType());
 
     result->dvalue = *a_dbl;
     result->svalue = *a_str;
