@@ -21,9 +21,7 @@
    
 *******************************************************************************/
 
-#include <boost/python.hpp>
-#include <tango.h>
-
+#include "precompiled_header.hpp"
 #include "server/attr.h"
 
 using namespace boost::python;
@@ -75,17 +73,17 @@ void PyAttr::set_user_prop(vector<Tango::AttrProperty> &user_prop,
         else if (prop_name == "delta_t")
             def_prop.set_delta_t(prop_value);
         else if (prop_name == "abs_change")
-            def_prop.set_abs_change(prop_value);
+            def_prop.set_event_abs_change(prop_value);
         else if (prop_name == "rel_change")
-            def_prop.set_rel_change(prop_value);
+            def_prop.set_event_rel_change(prop_value);
         else if (prop_name == "period")
-            def_prop.set_period(prop_value);
+            def_prop.set_event_period(prop_value);
         else if (prop_name == "archive_abs_change")
-            def_prop.set_archive_abs_change(prop_value);
+            def_prop.set_archive_event_abs_change(prop_value);
         else if (prop_name == "archive_rel_change")
-            def_prop.set_archive_rel_change(prop_value);
+            def_prop.set_archive_event_rel_change(prop_value);
         else if (prop_name == "archive_period")
-            def_prop.set_archive_period(prop_value);
+            def_prop.set_archive_event_period(prop_value);
     }
 }
 
@@ -105,6 +103,8 @@ void export_attr()
         .def("set_archive_event", &Tango::Attr::set_archive_event)
         .def("is_archive_event", &Tango::Attr::is_archive_event)
         .def("is_check_archive_criteria", &Tango::Attr::is_check_archive_criteria)
+        .def("set_data_ready_event", &Tango::Attr::set_data_ready_event)
+        .def("is_data_ready_event", &Tango::Attr::is_data_ready_event)
         .def("get_name", &Tango::Attr::get_name,
             return_value_policy<copy_non_const_reference>())
         .def("get_format", &Tango::Attr::get_format)
@@ -117,6 +117,9 @@ void export_attr()
         .def("get_assoc", &Tango::Attr::get_assoc,
             return_value_policy<copy_non_const_reference>())
         .def("is_assoc", &Tango::Attr::is_assoc)
+        .def("get_cl_name", &Tango::Attr::get_cl_name,
+            return_value_policy<copy_const_reference>())
+        .def("set_cl_name", &Tango::Attr::set_cl_name)
         .def("get_class_properties", &Tango::Attr::get_class_properties,
             return_internal_reference<>())
         .def("get_user_default_properties", &Tango::Attr::get_user_default_properties,
