@@ -21,33 +21,18 @@
    
 *******************************************************************************/
 
-#include <boost/python.hpp>
-#include <tango.h>
-#include <iostream>
-
+#include "precompiled_header.hpp"
 #include "defs.h"
 #include "pytgutils.h"
 #include "exception.h"
-
 #include "server/device_class.h"
 
 using namespace boost::python;
 
-/// @todo GET RID OF THIS!! I HATE "HERE_OLD_TANGO___"
-#ifndef WIN32
-# define HERE_OLD_TANGO___
-#endif
-
-#ifdef HERE_OLD_TANGO___
-    void Tango::DServer::class_factory()
-    {
-        Tango::DServer* dserver = this;
-#else
 namespace PyUtil
 {
     void _class_factory(Tango::DServer* dserver)
     {
-#endif
         AutoPythonGIL guard;
         PYTANGO_MOD
 
@@ -59,10 +44,10 @@ namespace PyUtil
         int cl_len = len(cpp_class_list);
         for(int i = 0; i < cl_len; ++i)
         {
-            tuple class_info = extract<tuple>(cpp_class_list[i]);
+            bopy::tuple class_info = extract<bopy::tuple>(cpp_class_list[i]);
             char *class_name = extract<char *>(class_info[0]);
             char *par_name   = extract<char *>(class_info[1]);
-            dserver->create_cpp_class(class_name, par_name);
+            dserver->_create_cpp_class(class_name, par_name);
         }
 
     //
@@ -78,26 +63,16 @@ namespace PyUtil
         for(int i = 0; i < cc_len; ++i)
         {
             CppDeviceClass *cpp_dc = extract<CppDeviceClass *> (constructed_classes[i])();
-            dserver->add_class(cpp_dc);
+            dserver->_add_class(cpp_dc);
         }
     }
 
-#ifdef HERE_OLD_TANGO___
-namespace PyUtil
-{
     void server_init(Tango::Util & instance, bool with_window = false)
     {
         AutoPythonAllowThreads guard;
+        Tango::DServer::register_class_factory(_class_factory);
         instance.server_init(with_window);
     }
-#else
-    void server_init(Tango::Util & instance, bool with_window = false)
-    {
-        AutoPythonAllowThreads guard;
-        instance.set_class_factory_cb(_class_factory);
-        instance.server_init(with_window);
-    }
-#endif
 
     void server_run(Tango::Util & instance)
     {
@@ -118,10 +93,11 @@ namespace PyUtil
         Tango::Util* res = 0;
 
         try {
-
             for(int i = 0; i < argc; ++i)
             {
-                argv[i] = PyString_AsString(PySequence_GetItem(obj_ptr, i));
+                PyObject* item_ptr = PySequence_GetItem(obj_ptr, i);
+                str item = str(handle<>(item_ptr));
+                argv[i] = extract<char *>(item);
             }
             res = Tango::Util::init(argc, argv);
         } catch (...) {
@@ -243,6 +219,9 @@ void export_util()
         .def("trigger_attr_polling", &Tango::Util::trigger_attr_polling)
         .def("set_polling_threads_pool_size", &Tango::Util::set_polling_threads_pool_size)
         .def("get_polling_threads_pool_size", &Tango::Util::get_polling_threads_pool_size)
+        .def("is_svr_starting", &Tango::Util::is_svr_starting)
+        .def("is_svr_shutting_down", &Tango::Util::is_svr_shutting_down)        
+        .def("is_device_restarting", &Tango::Util::is_device_restarting)        
         .def("get_sub_dev_diag", &Tango::Util::get_sub_dev_diag,
             return_internal_reference<>())
         .def("connect_db", &Tango::Util::connect_db)
@@ -258,4 +237,4 @@ void export_util()
         .def("init_python", init_python)
         .staticmethod("init_python")
     ;
-}
\ No newline at end of file
+}
